@@ -3,7 +3,6 @@ import logging
 from typing import Any, Callable
 from cache_house.backends.redis_backend import RedisCache
 from cache_house.backends.redis_cluster_backend import RedisClusterCache
-from redis.connection import parse_url
 
 from cache_house.helpers import (
     DEFAULT_NAMESPACE,
@@ -54,11 +53,12 @@ class RedisFactory:
         key_prefix: str = DEFAULT_PREFIX,
         key_builder: Callable[..., Any] = key_builder,
         cluster_mode: bool = False,
+        fallback_to_memory: bool = True,
         **redis_kwargs,
     ):
-        # print(parse_url(host))
         if not cls.instance:
-            backend = None
+            # Cache classes handle connection errors gracefully internally
+            # Redis client will handle reconnection automatically
             try:
                 if cluster_mode:
                     backend = RedisClusterCache(
@@ -69,6 +69,7 @@ class RedisFactory:
                         namespace=namespace,
                         key_prefix=key_prefix,
                         key_builder=key_builder,
+                        fallback_to_memory=fallback_to_memory,
                         url=None,
                         **redis_kwargs,
                     )
@@ -83,24 +84,31 @@ class RedisFactory:
                         namespace=namespace,
                         key_prefix=key_prefix,
                         key_builder=key_builder,
+                        fallback_to_memory=fallback_to_memory,
                         **redis_kwargs,
                     )
                 cls.instance = backend.instance
             except Exception as err:
-                log.error(err)
+                # Handle any unexpected errors during initialization
+                log.error(f"Failed to initialize Redis cache: {err}")
+                log.warning("Cache operations will be skipped until Redis is available.")
 
 
     @classmethod
     def get_instance(cls):
         if cls.instance:
             return cls.instance
-        log.error("Redis is not intialized")
+        log.warning("Redis is not initialized. Cache operations will be skipped.")
+        return None
 
     @classmethod
     def close_connections(cls):
         if cls.instance:
-            cls.instance.redis.close()
-            log.info("close redis connection")
+            try:
+                cls.instance.redis.close()
+                log.info("close redis connection")
+            except Exception as e:
+                log.warning(f"Error closing Redis connection: {e}")
 
 
 __all__ = [
